@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:03:12
-@LastEditTime: 2021-09-14 19:41:58
+@LastEditTime: 2021-09-17 17:50:40
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -12,11 +12,13 @@ from seven_cloudapp_frame.models.act_base_model import *
 from seven_cloudapp_frame.models.prize_base_model import *
 
 
-class ActInfoHandler(TaoBaseHandler):
+class ActInfoHandler(ClientBaseHandler):
     """
     :description: 获取活动信息
     """
     @filter_check_params("act_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 获取活动信息
@@ -24,7 +26,7 @@ class ActInfoHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
         app_base_model = AppBaseModel(context=self)
         act_base_model = ActBaseModel(context=self)
@@ -43,11 +45,13 @@ class ActInfoHandler(TaoBaseHandler):
         return self.response_json_success(act_info_dict)
 
 
-class ActPrizeListHandler(TaoBaseHandler):
+class ActPrizeListHandler(ClientBaseHandler):
     """
     :description: 活动奖品列表
     """
     @filter_check_params("act_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 活动奖品列表
@@ -60,7 +64,7 @@ class ActPrizeListHandler(TaoBaseHandler):
         :return: PageInfo
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
         module_id = int(self.get_param("module_id", 0))
         prize_name = self.get_param("prize_name")
