@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 13:37:05
-@LastEditTime: 2021-09-14 19:42:22
+@LastEditTime: 2021-09-17 17:52:36
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -10,11 +10,13 @@ from seven_cloudapp_frame.models.ip_base_model import *
 from seven_cloudapp_frame.handlers.frame_base import *
 
 
-class IpInfoListHandler(TaoBaseHandler):
+class IpInfoListHandler(ClientBaseHandler):
     """
     :description: 获取ip列表
     """
     @filter_check_params("act_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 获取ip列表
@@ -24,7 +26,7 @@ class IpInfoListHandler(TaoBaseHandler):
         :return: list
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 10))
