@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2021-09-14 19:44:44
+@LastEditTime: 2021-09-18 17:51:31
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -10,11 +10,13 @@ from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.task_base_model import *
 
 
-class TaskInfoListHandler(TaoBaseHandler):
+class TaskInfoListHandler(ClientBaseHandler):
     """
     :description: 获取任务列表
     """
     @filter_check_params("act_id,tb_user_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 获取任务列表
@@ -25,9 +27,9 @@ class TaskInfoListHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         task_types = self.get_param("task_types")
         is_log = self.get_param("is_log", False)
@@ -61,11 +63,13 @@ class TaskInfoListHandler(TaoBaseHandler):
         return task_list
 
 
-class ReceiveRewardHandler(TaoBaseHandler):
+class ReceiveRewardHandler(ClientBaseHandler):
     """
     :description: 处理领取任务奖励
     """
     @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理领取任务奖励
@@ -79,9 +83,9 @@ class ReceiveRewardHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         task_id = int(self.get_param("task_id"),0)
@@ -138,11 +142,13 @@ class ReceiveRewardHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class FreeGiftHandler(TaoBaseHandler):
+class FreeGiftHandler(ClientBaseHandler):
     """
     :description: 处理掌柜有礼、新人有礼、免费领取等相似任务
     """
     @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理掌柜有礼、新人有礼、免费领取等相似任务
@@ -154,9 +160,9 @@ class FreeGiftHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
@@ -208,11 +214,13 @@ class FreeGiftHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class OneSignHandler(TaoBaseHandler):
+class OneSignHandler(ClientBaseHandler):
     """
     :description: 处理单次签到任务
     """
     @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理单次签到任务
@@ -224,9 +232,9 @@ class OneSignHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
@@ -278,11 +286,13 @@ class OneSignHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class WeeklySignHandler(TaoBaseHandler):
+class WeeklySignHandler(ClientBaseHandler):
     """
     :description: 处理每周签到任务
     """
     @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理每周签到任务
@@ -294,9 +304,9 @@ class WeeklySignHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
@@ -348,11 +358,13 @@ class WeeklySignHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class CumulativeSignHandler(TaoBaseHandler):
+class CumulativeSignHandler(ClientBaseHandler):
     """
     :description: 处理累计签到任务
     """
     @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理累计签到任务
@@ -364,9 +376,9 @@ class CumulativeSignHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
@@ -418,11 +430,13 @@ class CumulativeSignHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class InviteNewUserHandler(TaoBaseHandler):
+class InviteNewUserHandler(ClientBaseHandler):
     """
     :description: 处理邀请新用户任务
     """
     @filter_check_params("act_id,tb_user_id,invite_user_id,login_token")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理邀请新用户任务
@@ -435,9 +449,9 @@ class InviteNewUserHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         invite_user_id = int(self.get_param("invite_user_id", 0))
@@ -490,11 +504,13 @@ class InviteNewUserHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class InviteJoinMemberHandler(TaoBaseHandler):
+class InviteJoinMemberHandler(ClientBaseHandler):
     """
     :description: 处理邀请加入会员任务
     """
     @filter_check_params("act_id,tb_user_id,invite_user_id,login_token")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理邀请加入会员任务
@@ -507,9 +523,9 @@ class InviteJoinMemberHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         invite_user_id = int(self.get_param("invite_user_id", 0))
@@ -521,7 +537,7 @@ class InviteJoinMemberHandler(TaoBaseHandler):
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = task_base_model.process_invite_join_member(app_id, act_id, module_id, user_id, login_token, invite_user_id, self.__class__.__name__, self.get_taobao_param().access_token, app_key, app_secret, check_user_nick, continue_request_expire)
+        invoke_result_data = task_base_model.process_invite_join_member(app_id, act_id, module_id, user_id, login_token, invite_user_id, self.__class__.__name__, self.get_param("access_token"), app_key, app_secret, check_user_nick, continue_request_expire)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token, invite_user_id, self.request_params)
@@ -563,11 +579,13 @@ class InviteJoinMemberHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class CollectGoodsHandler(TaoBaseHandler):
+class CollectGoodsHandler(ClientBaseHandler):
     """
     :description: 处理收藏商品任务
     """
     @filter_check_params("act_id,tb_user_id,login_token,goods_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理收藏商品任务
@@ -580,9 +598,9 @@ class CollectGoodsHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         goods_id = self.get_param("goods_id")
         login_token = self.get_param("login_token")
@@ -633,11 +651,13 @@ class CollectGoodsHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class BrowseGoodsHandler(TaoBaseHandler):
+class BrowseGoodsHandler(ClientBaseHandler):
     """
     :description: 处理浏览商品任务
     """
     @filter_check_params("act_id,tb_user_id,login_token,goods_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理浏览商品任务
@@ -650,9 +670,9 @@ class BrowseGoodsHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         goods_id = self.get_param("goods_id")
         login_token = self.get_param("login_token")
@@ -704,11 +724,13 @@ class BrowseGoodsHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class FavorStoreHandler(TaoBaseHandler):
+class FavorStoreHandler(ClientBaseHandler):
     """
     :description: 处理关注店铺
     """
     @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理关注店铺
@@ -720,9 +742,9 @@ class FavorStoreHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
@@ -773,11 +795,13 @@ class FavorStoreHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class JoinMemberHandler(TaoBaseHandler):
+class JoinMemberHandler(ClientBaseHandler):
     """
     :description: 处理加入店铺会员
     """
     @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理加入店铺会员
@@ -789,9 +813,9 @@ class JoinMemberHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
@@ -842,11 +866,13 @@ class JoinMemberHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class BrowseSiteHandler(TaoBaseHandler):
+class BrowseSiteHandler(ClientBaseHandler):
     """
     :description: 处理浏览网址相关任务 如：浏览店铺、浏览直播间、浏览会场/专题
     """
     @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理浏览商品任务
@@ -860,9 +886,9 @@ class BrowseSiteHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         task_type = int(self.get_param("task_type", 0))
         task_sub_type = self.get_param("task_sub_type")
