@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:15:49
-@LastEditTime: 2021-09-14 19:45:44
+@LastEditTime: 2021-09-17 18:06:42
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -11,11 +11,13 @@ from seven_cloudapp_frame.models.theme_base_model import *
 from seven_cloudapp_frame.models.act_base_model import *
 
 
-class ThemeInfoHandler(TaoBaseHandler):
+class ThemeInfoHandler(ClientBaseHandler):
     """
     :description: 获取主题（皮肤）信息
     """
     @filter_check_params("act_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 获取主题（皮肤）信息
@@ -37,11 +39,13 @@ class ThemeInfoHandler(TaoBaseHandler):
         return self.response_json_success(theme_info)
 
 
-class SaveThemeHandler(TaoBaseHandler):
+class SaveThemeHandler(ClientBaseHandler):
     """
     :description: 保存主题
     """
     @filter_check_params("out_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def post_async(self):
         """
         :description: 保存主题
@@ -54,7 +58,7 @@ class SaveThemeHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         theme_name = self.get_param("theme_name")
         client_json = self.get_param("client_json")
         server_json = self.get_param("server_json")
@@ -66,11 +70,13 @@ class SaveThemeHandler(TaoBaseHandler):
         return self.response_json_success()
 
 
-class SaveSkinHandler(TaoBaseHandler):
+class SaveSkinHandler(ClientBaseHandler):
     """
     :description: 保存皮肤
     """
     @filter_check_params("theme_out_id,skin_out_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def post_async(self):
         """
         :description: 保存皮肤
@@ -83,7 +89,7 @@ class SaveSkinHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         skin_name = self.get_param("skin_name")
         client_json = self.get_param("client_json")
         server_json = self.get_param("server_json")
@@ -97,10 +103,12 @@ class SaveSkinHandler(TaoBaseHandler):
         return self.response_json_success(invoke_result_data.data)
 
 
-class ThemeInfoListHandler(TaoBaseHandler):
+class ThemeInfoListHandler(ClientBaseHandler):
     """
     :description: 获取主题信息列表
     """
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 保存皮肤
@@ -108,16 +116,18 @@ class ThemeInfoListHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         theme_base_model = ThemeBaseModel(context=self)
         return self.response_json_success(theme_base_model.get_theme_list(app_id))
 
 
-class SkinInfoListHandler(TaoBaseHandler):
+class SkinInfoListHandler(ClientBaseHandler):
     """
     :description: 获取皮肤信息列表
     """
     @filter_check_params("theme_out_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 保存皮肤
