@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-09-14 19:41:31
+@LastEditTime: 2021-09-28 10:44:57
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -28,6 +28,8 @@ class FrameBaseHandler(BaseApiHandler):
     """
     :description: 公共handler基类
     """
+    request_params = {}  # 请求参数
+
     def options_async(self):
         self.response_json_success()
 
@@ -87,10 +89,11 @@ class FrameBaseHandler(BaseApiHandler):
         :last_editors: HuangJianYi
         """
         param_ret = ""
-        if self.request.method == "POST" and self.request.body:
-            if not self.param_info:
-                self.param_info = json.loads(self.request.body)
-            param_ret = self.param_info[param_name] if self.param_info.__contains__(param_name) else ""
+
+        if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
+            if not self.request_params:
+                self.request_params = json.loads(self.request.body)
+            param_ret = self.request_params[param_name] if self.request_params.__contains__(param_name) else ""
         else:
             param_ret = self.get_argument(param_name, default, strip=strip)
         if param_ret == "" or param_ret == "undefined":
@@ -104,11 +107,11 @@ class FrameBaseHandler(BaseApiHandler):
         :return: 将dumps后的数据字符串返回给客户端
         :last_editors: HuangJianYi
         """
-        reponse_result_encrypt = config.get_value("reponse_result_encrypt", False)
-        if reponse_result_encrypt == True:
-            self.http_reponse("0" + self.base64_encode(self.json_dumps(rep_dic)))
+        response_encrypt = config.get_value("response_encrypt", False)
+        if response_encrypt == True:
+            self.http_response("0" + self.base64_encode(self.json_dumps(rep_dic)))
         else:
-            self.http_reponse(self.json_dumps(rep_dic))
+            self.http_response(self.json_dumps(rep_dic))
 
     def response_common(self, success=True, data=None, error_code="", error_message=""):
         """
@@ -265,7 +268,7 @@ class FrameBaseHandler(BaseApiHandler):
         :last_editors: HuangJianYi
         """
         redis_init = SevenHelper.redis_init()
-        cache_key = f"request_user_list:{app_id}_{str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M'))}"
+        cache_key = f"request_user_list_{app_id}:{str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M'))}"
         redis_init.sadd(cache_key, object_id)
         redis_init.expire(cache_key, 3600)
 
@@ -282,14 +285,14 @@ class FrameBaseHandler(BaseApiHandler):
             return False
         redis_init = SevenHelper.redis_init()
         if current_limit_minute == 1:
-            cache_key = f"request_user_list:{app_id}_{str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M'))}"
+            cache_key = f"request_user_list_{app_id}:{str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M'))}"
         else:
             key_list = []
             for i in range(current_limit_minute):
                 now_minute_int = int((datetime.datetime.now() + datetime.timedelta(minutes=-i)).strftime('%Y%m%d%H%M'))
-                key = f"request_user_list:{app_id}_{str(now_minute_int)}"
+                key = f"request_user_list_{app_id}:{str(now_minute_int)}"
                 key_list.append(key)
-            cache_key = f"request_user_list:{app_id}"
+            cache_key = f"request_user_list_{app_id}"
             redis_init.sinterstore(cache_key, key_list)
             redis_init.expire(cache_key, 3600)
 
@@ -327,11 +330,14 @@ class FrameBaseHandler(BaseApiHandler):
         self.set_header("Access-Control-Allow-Credentials", "true")
 
 
-class TaoBaseHandler(FrameBaseHandler):
+class ClientBaseHandler(FrameBaseHandler):
 
     """
-    :description: 淘宝handler基类
+    :description: handler基类
     """
+
+    device_info_dict = {}  # 头部参数
+
     def prepare(self):
         """
         :Description: 置于任何请求方法前被调用(请勿重写此函数,可重写prepare_ext)
@@ -340,105 +346,106 @@ class TaoBaseHandler(FrameBaseHandler):
         if self.__class__.__name__ == "IndexHandler":
             return
 
-        dict_par = {}
-        dict_par["open_id"] = self.get_taobao_param().open_id
-        dict_par["nick_name"] = self.get_taobao_param().user_nick
-        dict_par["app_id"] = self.get_param("app_id")
-        if not dict_par["app_id"]:
-            dict_par["app_id"] = self.get_taobao_param().source_app_id
+        dict_param = {}
+        dict_param["open_id"] = self.get_open_id()
+        if not dict_param["open_id"]:
+            dict_param["open_id"] = self.get_user_id()
+        dict_param["nick_name"] = self.get_user_nick()
+        dict_param["app_id"] = self.get_app_id()
+        if not dict_param["app_id"]:
+            dict_param["app_id"] = self.get_source_app_id()
 
         try:
             # 标记日志请求关联
-            self._build_http_log(dict_par)
+            self._build_http_log(dict_param)
 
-            if dict_par["app_id"] and dict_par["open_id"]:
+            # 将设备信息字符串转为字典类型
+            clientheaderinfo_string = self.request.headers._dict.get("Clientheaderinfo")
+            if clientheaderinfo_string:
+                self.device_info_dict = self.get_device_info_dict(clientheaderinfo_string)
+
+            if dict_param["open_id"]:
                 # 频繁请求校验
-                is_continue_request, error_message = self.check_continue_request(self.__class__.__name__, dict_par["app_id"], dict_par["open_id"])
+                is_continue_request, error_message = self.check_continue_request(self.__class__.__name__, dict_param["app_id"], dict_param["open_id"])
                 if is_continue_request:
                     return self.response_json_error("error", error_message)
 
                 #每分钟流量UV计数,用于登录接口限制登录
-                self.add_request_user(str(dict_par["app_id"]), str(dict_par["open_id"]))
+                self.add_request_user(str(dict_param["app_id"]), str(dict_param["open_id"]))
 
         except Exception as ex:
-            self.logging_link_error("【淘宝handler基类】" + str(ex))
+            self.logging_link_error("【handler基类】" + str(ex))
 
-    def get_taobao_param(self):
+    def get_user_nick(self):
         """
-        :description: 获取淘宝上下文参数
-        :return: TaoBaoParam
+        :description: 获取用户昵称
+        :param self
+        :return str
         :last_editors: HuangJianYi
         """
-        app_key = self.get_param("app_key")
         user_nick = self.get_param("user_nick")
-        open_id = self.get_param("open_id")
-        env = self.get_param("env")
-        mini_app_id = self.get_param("mini_app_id")
-        access_token = self.get_param("access_token")
-        sign = self.get_param("sign")
-        mix_nick = self.get_param("mix_nick")
-        tb_user_id = self.get_param("tb_user_id")
-        main_user_id = self.get_param("main_user_id")
-        source_app_id = self.get_param("source_app_id")
-        request_id = self.get_param("request_id")
+        if self.get_param("source_app_id") == "":
+            #前端（在IDE上返回前端模板id，在千牛上返回正确的id）
+            user_nick = config.get_value("test_user_nick")
+        return user_nick
 
-        #region 指定测试账号和小程序,用于在IDE上测试(前端通过source_app_id关联数据,后端通过user_nick关联数据)
+    def get_open_id(self):
+        """
+        :description: 获取open_id
+        :param self
+        :return str
+        :last_editors: HuangJianYi
+        """
+        open_id = self.get_param("open_id")
+        if self.get_param("source_app_id") == "":
+            #前端（在IDE上返回前端模板id，在千牛上返回正确的id）
+            open_id = config.get_value("test_open_id")
+        return open_id
+
+    def get_user_id(self):
+        """
+        :description: 获取user_id
+        :param self
+        :return str
+        :last_editors: HuangJianYi
+        """
+        user_id = int(self.get_param("tb_user_id", 0))
+        if user_id == 0:
+            user_id = int(self.get_param("user_id",0))
+        return user_id
+
+    def get_source_app_id(self):
+        """
+        :description: 获取source_app_id(客户端使用)
+        :param self
+        :return str
+        :last_editors: HuangJianYi
+        """
+        source_app_id = self.get_param("source_app_id")
         if source_app_id == config.get_value("client_template_id"):
             #前端（在IDE上返回前端模板id，在千牛上返回正确的id）
             source_app_id = config.get_value("test_source_app_id")
-        if source_app_id == "":
-            #后端（在IDE上返回空，在千牛上返回后端模板ids）
-            source_app_id = config.get_value("test_source_app_id")
-            user_nick = config.get_value("test_user_nick")
-            open_id = config.get_value("test_open_id")
-        #endregion
-
-        info = TaoBaoParam()
-        info.app_key = app_key
-        info.user_nick = user_nick
-        info.open_id = open_id
-        info.env = env
-        info.mini_app_id = mini_app_id
-        info.access_token = access_token
-        info.sign = sign
-        info.mix_nick = mix_nick
-        info.tb_user_id = tb_user_id
-        info.main_user_id = main_user_id
-        info.source_app_id = source_app_id
-        info.request_id = request_id
-
-        return info
+        return source_app_id
 
     def get_app_id(self):
         """
-        :description: 获取app_id(千牛端使用)
+        :description: 获取app_id(后台使用)
         :param self
         :return str
         :last_editors: HuangJianYi
         """
         app_id = self.get_param("app_id")
         if app_id == "":
-            user_nick = self.get_taobao_param().user_nick
-            if user_nick:
+            plat_type = config.get_value("plat_type", 1)  # 平台类型 1淘宝2微信3抖音
+            user_nick = self.get_user_nick()
+            if user_nick and plat_type ==1:
                 store_user_nick = user_nick.split(':')[0]
                 if store_user_nick:
                     app_info_dict = AppInfoModel(context=self).get_cache_dict(where="store_user_nick=%s", field="app_id", params=store_user_nick)
                     if app_info_dict:
                         app_id = app_info_dict["app_id"]
-            else:
-                app_id = config.get_value("test_source_app_id")
         return app_id
 
-    def get_is_test(self):
-        """
-        :description: 判断是否本地测试
-        :return: bool
-        :last_editors: HuangJianYi
-        """
-        if self.get_taobao_param().env != "online":
-            return True
-        return False
-
     def get_online_url(self, act_id, app_id, module_id=0):
         """
         :description: 获取online_url
@@ -485,10 +492,10 @@ class TaoBaseHandler(FrameBaseHandler):
         operation_log = OperationLog()
         operation_log_model = OperationLogModel(context=self)
 
-        operation_log.user_nick = self.get_taobao_param().user_nick
-        operation_log.app_id = self.get_taobao_param().source_app_id
+        operation_log.app_id = ""
         operation_log.act_id = int(self.get_param("act_id", 0))
-        operation_log.open_id = self.get_taobao_param().open_id
+        operation_log.open_id = self.get_open_id()
+        operation_log.user_nick = self.get_user_nick()
         operation_log.request_params = self.request_params
         operation_log.method = self.request.method
         operation_log.protocol = self.request.protocol
@@ -513,45 +520,7 @@ class TaoBaseHandler(FrameBaseHandler):
 
         operation_log_model.add_entity(operation_log)
 
-
-class ClientBaseHandler(FrameBaseHandler):
-    """
-    :description: 客户端handler基类
-    """
-    device_info_dict = {}  # 头部参数
-
-    def prepare_ext(self):
-        """
-        :Description: 置于任何请求方法前被调用(请勿重写此函数,可重写prepare_ext)
-        :last_editors: HuangJianYi
-        """
-        if self.__class__.__name__ == "IndexHandler":
-            return
-
-        dict_par = {}
-        dict_par["open_id"] = self.get_param("user_id")
-        dict_par["app_id"] = self.get_param("app_id","1")
-
-        try:
-            # 将设备信息字符串转为字典类型
-            clientheaderinfo_string = self.request.headers._dict.get("Clientheaderinfo")
-            if clientheaderinfo_string:
-                self.device_info_dict = self.device_info_dict(clientheaderinfo_string)
-
-            user_id = self.get_param("user_id")
-            if user_id:
-                # 频繁请求校验
-                is_continue_request, error_message = self.check_continue_request(self.__class__.__name__, dict_par["app_id"], user_id)
-                if is_continue_request:
-                    return self.response_json_error("error", error_message)
-                #每分钟流量UV计数,用于登录接口限制登录
-                self.add_request_user(str(dict_par["app_id"]), user_id)
-
-        except Exception as ex:
-            self.logging_link_error("【客户端handler基类】" + str(ex))
-
-
-    def device_info_dict(self, device_str):
+    def get_device_info_dict(self, device_str):
         """
         :description: 获取头部参数字典
         :param device_string:头部信息串
@@ -589,11 +558,14 @@ def filter_check_params(must_params=None):
     def check_params(handler):
         def wrapper(self, **args):
             self.request_params = {}
-            if type(must_params) == str:
-                must_array = must_params.split(",")
-            if type(must_params) == list:
-                must_array = must_params
-            if self.request.method == "POST" and self.request.body:
+            finally_must_params = must_params
+            if hasattr(self, "must_params"):
+                finally_must_params = self.must_params
+            if type(finally_must_params) == str:
+                must_array = finally_must_params.split(",")
+            if type(finally_must_params) == list:
+                must_array = finally_must_params
+            if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
                 json_params = {}
                 try:
                     json_params = json.loads(self.request.body)
@@ -606,7 +578,7 @@ def filter_check_params(must_params=None):
             else:
                 for field in self.request.arguments:
                     self.request_params[field] = self.get_param(field)
-            if must_params:
+            if finally_must_params:
                 for must_param in must_array:
                     if not must_param in self.request_params or self.request_params[must_param] == "":
                         self.response_json_error("ParamError", "参数错误,缺少必传参数")
@@ -628,7 +600,7 @@ def filter_check_head_sign(is_check=True, no_check_params=None):
     def check_head(handler):
         def wrapper(self, **args):
             encrypt_key = config.get_value("encrypt_key", "3924e337a476475e95b2b341eaba8c1c")
-            is_check_head = config.get_value("is_check_head", True)
+            is_check_head = config.get_value("is_check_head", False)
             if is_check_head == False:
                 is_check = False
             else:
@@ -682,7 +654,7 @@ def filter_check_params_sign(is_check=True, no_check_params=None):
     def check_params(handler):
         def wrapper(self, **args):
             encrypt_key = config.get_value("encrypt_key", "3924e337a476475e95b2b341eaba8c1c")
-            is_check_params = config.get_value("is_check_params", True)
+            is_check_params = config.get_value("is_check_params", False)
             if is_check_params == False:
                 is_check = False
             else:
