@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-09-14 19:46:58
+@LastEditTime: 2021-09-17 19:42:25
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -12,7 +12,7 @@ from seven_cloudapp_frame.models.module_base_model import *
 from seven_cloudapp_frame.models.seven_model import PageInfo
 
 
-class SaveActModuleHandler(TaoBaseHandler):
+class SaveActModuleHandler(ClientBaseHandler):
     """
     :description: 保存活动模块信息
     """
@@ -87,9 +87,9 @@ class SaveActModuleHandler(TaoBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
             # 记录日志
-            self.create_operation_log(OperationType.add.value, invoke_result_data.data["new"].__str__(), "SaveActModuleHandler", None, self.json_dumps(invoke_result_data.data["new"]), self.get_taobao_param().open_id, self.get_taobao_param().user_nick)
+            self.create_operation_log(OperationType.add.value, invoke_result_data.data["new"].__str__(), "SaveActModuleHandler", None, self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
         else:
-            self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SaveActModuleHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_taobao_param().open_id, self.get_taobao_param().user_nick)
+            self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SaveActModuleHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
         self.response_json_success(invoke_result_data.data["new"].id)
 
     def business_process_executing(self, app_id, act_id, module_id, module_name, module_sub_name, start_date, end_date, module_pic, module_desc, price, price_gear_id, ip_id, join_ways, is_fictitious, sort_index, is_release, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2):
@@ -130,7 +130,7 @@ class SaveActModuleHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class ActModuleHandler(TaoBaseHandler):
+class ActModuleHandler(ClientBaseHandler):
     """
     :description: 单条活动模块信息
     """
@@ -154,7 +154,7 @@ class ActModuleHandler(TaoBaseHandler):
         return self.response_json_success(act_module_dict)
 
 
-class ActModuleListHandler(TaoBaseHandler):
+class ActModuleListHandler(ClientBaseHandler):
     """
     :description: 活动模块列表
     """
@@ -180,13 +180,33 @@ class ActModuleListHandler(TaoBaseHandler):
         start_date = self.get_param("start_date")
         end_date = self.get_param("end_date")
 
+        condition = ""
+        params = []
+        order_by = "create_date desc"
+        invoke_result_data = self.business_process_executing(self.request_params)
+        if invoke_result_data.success == True:
+            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc,id asc"
+
         if not app_id or not act_id:
             return self.response_json_success({"data": []})
         module_base_model = ModuleBaseModel(context=self)
-        page_list, total = module_base_model.get_act_module_list(app_id, act_id, module_name, start_date, end_date, is_del, page_size, page_index, False)
+        page_list, total = module_base_model.get_act_module_list(app_id, act_id, module_name, start_date, end_date, is_del, page_size, page_index, order_by=order_by, condition=condition, params=params,is_cache=False)
         page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list))
         return self.response_json_success(page_info)
 
+    def business_process_executing(self, request_params):
+        """
+        :description: 执行前事件
+        :param request_params: 请求参数字典
+        :return:
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        invoke_result_data.data = {"condition": "", "params": [], "order_by": "sort_index desc,id asc"}
+        return invoke_result_data
+
     def business_process_executed(self, page_list):
         """
         :description: 执行后事件
@@ -197,7 +217,7 @@ class ActModuleListHandler(TaoBaseHandler):
         return page_list
 
 
-class DeleteActModuleHandler(TaoBaseHandler):
+class DeleteActModuleHandler(ClientBaseHandler):
     """
     :description: 删除活动模块
     """
@@ -234,7 +254,7 @@ class DeleteActModuleHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class ReviewActModuleHandler(TaoBaseHandler):
+class ReviewActModuleHandler(ClientBaseHandler):
     """
     :description: 还原活动模块
     """
@@ -271,7 +291,7 @@ class ReviewActModuleHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class ReleaseActModuleHandler(TaoBaseHandler):
+class ReleaseActModuleHandler(ClientBaseHandler):
     """
     :description: 上下架活动模块
     """
@@ -310,7 +330,7 @@ class ReleaseActModuleHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class UpdateActModulePriceHandler(TaoBaseHandler):
+class UpdateActModulePriceHandler(ClientBaseHandler):
     """
     :description: 更新活动模块价格
     """
