@@ -13,7 +13,7 @@ from seven_cloudapp_frame.models.prize_base_model import *
 from seven_cloudapp_frame.models.seven_model import PageInfo
 
 
-class SaveActPrizeHandler(TaoBaseHandler):
+class SaveActPrizeHandler(ClientBaseHandler):
     """
     :description: 保存活动奖品
     """
@@ -111,14 +111,14 @@ class SaveActPrizeHandler(TaoBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
             # 记录日志
-            self.create_operation_log(OperationType.add.value, invoke_result_data.data["new"].__str__(), "SaveActPrizeHandler", None, self.json_dumps(invoke_result_data.data["new"]), self.get_taobao_param().open_id, self.get_taobao_param().user_nick)
+            self.create_operation_log(OperationType.add.value, invoke_result_data.data["new"].__str__(), "SaveActPrizeHandler", None, self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
         else:
-            self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SaveActPrizeHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_taobao_param().open_id, self.get_taobao_param().user_nick)
+            self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SaveActPrizeHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
 
         self.response_json_success(invoke_result_data.data["new"].id)
 
 
-class ActPrizeListHandler(TaoBaseHandler):
+class ActPrizeListHandler(ClientBaseHandler):
     """
     :description: 活动奖品列表
     """
@@ -150,7 +150,7 @@ class ActPrizeListHandler(TaoBaseHandler):
         return self.response_json_success(page_info)
 
 
-class DeleteActPrizeHandler(TaoBaseHandler):
+class DeleteActPrizeHandler(ClientBaseHandler):
     """
     :description: 删除活动奖品
     """
@@ -173,7 +173,7 @@ class DeleteActPrizeHandler(TaoBaseHandler):
         return self.response_json_success()
 
 
-class ReviewActPrizeHandler(TaoBaseHandler):
+class ReviewActPrizeHandler(ClientBaseHandler):
     """
     :description: 还原活动奖品
     """
@@ -197,7 +197,7 @@ class ReviewActPrizeHandler(TaoBaseHandler):
         return self.response_json_success()
 
 
-class ReleaseActPrizeHandler(TaoBaseHandler):
+class ReleaseActPrizeHandler(ClientBaseHandler):
     """
     :description: 上下架活动奖品
     """
