@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:52:51
-@LastEditTime: 2021-09-14 19:48:09
+@LastEditTime: 2021-09-23 16:38:02
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -15,7 +15,7 @@ from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.models.db_models.tao.tao_login_log_model import *
 
 
-class LoginHandler(TaoBaseHandler):
+class LoginHandler(ClientBaseHandler):
     """
     :description: 登录处理
     """
@@ -28,8 +28,8 @@ class LoginHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        open_id = self.get_taobao_param().open_id
-        user_nick = self.get_taobao_param().user_nick
+        open_id = self.get_open_id()
+        user_nick = self.get_user_nick()
 
         request_params = str(self.request_params)
 
@@ -72,7 +72,7 @@ class LoginHandler(TaoBaseHandler):
         self.response_json_success()
 
 
-class UpdateUserStatusHandler(TaoBaseHandler):
+class UpdateUserStatusHandler(ClientBaseHandler):
     """
     :description: 更新用户状态
     """
@@ -89,16 +89,16 @@ class UpdateUserStatusHandler(TaoBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id"))
-        tb_user_id = int(self.get_param("tb_user_id"))
+        user_id = self.get_user_id()
         user_state = int(self.get_param("user_state"))
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = user_base_model.update_user_state(app_id, act_id, tb_user_id, user_state)
+        invoke_result_data = user_base_model.update_user_state(app_id, act_id, user_id, user_state)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
         self.response_json_success()
 
 
-class UpdateUserStatusByBlackHandler(TaoBaseHandler):
+class UpdateUserStatusByBlackHandler(ClientBaseHandler):
     """
     :description: 用户拉入黑名单(黑名单管理模式)
     """
@@ -114,15 +114,38 @@ class UpdateUserStatusByBlackHandler(TaoBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id"))
-        tb_user_id = int(self.get_param("tb_user_id"))
+        user_id = self.get_user_id()
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = user_base_model.update_user_state_by_black(app_id, act_id, tb_user_id)
+        invoke_result_data = user_base_model.update_user_state_by_black(app_id, act_id, user_id)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
+        self.business_process_executed(invoke_result_data)
         self.response_json_success()
 
+    def business_process_executing(self):
+        """
+        :description: 执行前事件
+        :return:
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        invoke_result_data.data = {}
+        return invoke_result_data
 
-class AuditUserBlackHandler(TaoBaseHandler):
+    def business_process_executed(self, invoke_result_data):
+        """
+        :description: 执行后事件
+        :param invoke_result_data:框架处理结果
+        :return:
+        :last_editors: HuangJianYi
+        """
+        return invoke_result_data
+
+
+class AuditUserBlackHandler(ClientBaseHandler):
     """
     :description 审核黑名单状态
     """
@@ -140,14 +163,38 @@ class AuditUserBlackHandler(TaoBaseHandler):
         black_id = int(self.get_param("black_id", 0))
         audit_status = int(self.get_param("audit_status", 0))
         audit_remark = self.get_param("audit_remark")
+
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         user_base_model = UserBaseModel(context=self)
         invoke_result_data = user_base_model.audit_user_black(app_id, black_id, audit_status, audit_remark)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
+        self.business_process_executed(invoke_result_data)
         self.response_json_success()
 
+    def business_process_executing(self):
+        """
+        :description: 执行前事件
+        :return:
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        invoke_result_data.data = {}
+        return invoke_result_data
 
-class UpdateAuditRemarkHandler(TaoBaseHandler):
+    def business_process_executed(self, invoke_result_data):
+        """
+        :description: 执行后事件
+        :param invoke_result_data:框架处理结果
+        :return:
+        :last_editors: HuangJianYi
+        """
+        return invoke_result_data
+
+
+class UpdateAuditRemarkHandler(ClientBaseHandler):
     """
     :description 修改审核备注
     """
@@ -170,7 +217,7 @@ class UpdateAuditRemarkHandler(TaoBaseHandler):
         self.response_json_success()
 
 
-class UserBlackListHandler(TaoBaseHandler):
+class UserBlackListHandler(ClientBaseHandler):
     """
     :description: 获取黑名单管理列表
     """
@@ -181,7 +228,7 @@ class UserBlackListHandler(TaoBaseHandler):
         :param app_id：应用标识
         :param act_id：活动标识
         :param audit_status：审核状态(0黑名单1申请中2同意3拒绝)
-        :param tb_user_id：用户标识
+        :param user_id：用户标识
         :param start_date：开始时间
         :param end_date：结束时间
         :param nick_name：用户昵称
@@ -194,7 +241,7 @@ class UserBlackListHandler(TaoBaseHandler):
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
         audit_status = int(self.get_param("audit_status", -1))
-        tb_user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         user_nick = self.get_param("nick_name")
         open_id = self.get_param("user_open_id")
         start_date = self.get_param("start_date")
@@ -203,10 +250,10 @@ class UserBlackListHandler(TaoBaseHandler):
         page_index = int(self.get_param("page_index", 0))
 
         user_base_model = UserBaseModel(context=self)
-        self.response_json_success(user_base_model.get_black_list(app_id, act_id, page_size, page_index, audit_status, tb_user_id, start_date, end_date, user_nick, open_id))
+        self.response_json_success(user_base_model.get_black_list(app_id, act_id, page_size, page_index, audit_status, user_id, start_date, end_date, user_nick, open_id))
 
 
-class UpdateUserAssetHandler(TaoBaseHandler):
+class UpdateUserAssetHandler(ClientBaseHandler):
     """
     :description: 变更资产
     """
@@ -216,7 +263,7 @@ class UpdateUserAssetHandler(TaoBaseHandler):
         :description: 变更资产
         :param app_id：应用标识
         :param act_id：活动标识
-        :param tb_user_id：用户标识
+        :param user_id：用户标识
         :param asset_type：资产类型
         :param asset_value：变更的资产值
         :param asset_object_id：资产对象标识
@@ -225,11 +272,15 @@ class UpdateUserAssetHandler(TaoBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         asset_type = int(self.get_param("asset_type", 0))
         asset_value = int(self.get_param("asset_value", 0))
         asset_object_id = self.get_param("asset_object_id")
 
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
+
         user_base_model = UserBaseModel(context=self)
         user_info_dict = user_base_model.get_user_info_dict(app_id, act_id, user_id)
         if not user_info_dict:
@@ -239,10 +290,36 @@ class UpdateUserAssetHandler(TaoBaseHandler):
         invoke_result_data = asset_base_model.update_user_asset(app_id, act_id, 0, user_id, user_info_dict["open_id"], user_info_dict["user_nick"], asset_type, asset_value, asset_object_id, 3, "", "手动配置", "手动配置")
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
+        self.business_process_executed(invoke_result_data)
         self.response_json_success()
 
+    def business_process_executing(self):
+        """
+        :description: 执行前事件
+        :return:
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        invoke_result_data.data = {}
+        return invoke_result_data
 
-class BatchUpdateUserAssetHandler(TaoBaseHandler):
+    def business_process_executed(self, invoke_result_data):
+        """
+        :description: 执行后事件
+        :param invoke_result_data:框架处理结果
+        :param app_id：应用标识
+        :param act_id：活动标识
+        :param module_id：活动模块标识
+        :param open_id：open_id
+        :param user_nick：昵称
+        :param avatar：头像
+        :return:
+        :last_editors: HuangJianYi
+        """
+        return invoke_result_data
+
+
+class BatchUpdateUserAssetHandler(ClientBaseHandler):
     """
     :description: 批量变更资产
     """
@@ -252,14 +329,14 @@ class BatchUpdateUserAssetHandler(TaoBaseHandler):
         :description: 批量变更资产
         :param app_id：应用标识
         :param act_id：活动标识
-        :param tb_user_id：用户标识
+        :param user_id：用户标识
         :param asset_object_json：变更的资产值列表
         :return: response_json_success
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         #{"asset_type":0,"asset_object_id":"","asset_value":0}
         asset_object_json = self.get_param("asset_object_json")
 
@@ -283,7 +360,7 @@ class BatchUpdateUserAssetHandler(TaoBaseHandler):
         self.response_json_success()
 
 
-class AssetLogListHandler(TaoBaseHandler):
+class AssetLogListHandler(ClientBaseHandler):
     """
     :description: 资产流水记录
     """
@@ -311,7 +388,7 @@ class AssetLogListHandler(TaoBaseHandler):
         act_id = int(self.get_param("act_id", 0))
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
-        tb_user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
         user_nick = self.get_param("nick_name")
         start_date = self.get_param("start_date")
@@ -322,10 +399,10 @@ class AssetLogListHandler(TaoBaseHandler):
         asset_object_id = self.get_param("asset_object_id")
 
         asset_base_model = AssetBaseModel(context=self)
-        self.response_json_success(asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, tb_user_id, asset_object_id, start_date, end_date, user_nick, user_open_id, source_type, source_object_id))
+        self.response_json_success(asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, start_date, end_date, user_nick, user_open_id, source_type, source_object_id))
 
 
-class UserInfoListHandler(TaoBaseHandler):
+class UserInfoListHandler(ClientBaseHandler):
     """
     :description: 用户信息列表
     """
@@ -334,7 +411,7 @@ class UserInfoListHandler(TaoBaseHandler):
         """
         :description: 用户信息列表
         :param act_id：活动标识
-        :param tb_user_id：用户标识
+        :param user_id：用户标识
         :param user_open_id：_open_id
         :param nick_name：用户昵称
         :param user_state：_用户状态0正常1黑名单
@@ -347,7 +424,7 @@ class UserInfoListHandler(TaoBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         open_id = self.get_param("user_open_id")
         user_nick = self.get_param("nick_name")
         user_state = int(self.get_param("user_state", -1))
