@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2021-09-06 15:44:54
+@LastEditTime: 2021-09-22 16:00:14
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -370,7 +370,10 @@ class SevenHelper:
         """
         if not start_date or not end_date:
             return []
-
+        if ":" not in start_date:
+            start_date+=" 00:00:00"
+        if ":" not in end_date:
+            end_date += " 00:00:00"
         datestart = datetime.datetime.strptime(start_date, '%Y-%m-%d %H:%M:%S')
         dateend = datetime.datetime.strptime(end_date, '%Y-%m-%d %H:%M:%S')
 
