@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-01-14 10:44:07
-@LastEditTime: 2021-09-14 19:21:27
+@LastEditTime: 2021-09-22 15:22:39
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -23,16 +23,19 @@ class TikTokHelper:
     logger_error = Logger.get_logger_by_name("log_error")
 
     @classmethod
-    def code2_session(self, app_id, app_secret, code="", anonymous_code=""):
+    def code2_session(self, code="", anonymous_code="", app_id="", app_secret=""):
         """
         :description:获取open_id、session_key等信息
-        :param app_id: app_id
-        :param app_secret: app_secret
         :param code: 登录票据,非匿名需要 code
         :param anonymous_code: 非匿名下的 anonymous_code 用于数据同步，匿名需要 anonymous_code
+        :param app_id: app_id
+        :param app_secret: app_secret
         :return: 
         :last_editors: HuangJianYi
         """
+        app_id = app_id if app_id else config.get_value("app_id")
+        app_secret = app_secret if app_secret else config.get_value("app_secret")
+
         invoke_result_data = InvokeResultData()
         redis_key = f"{app_id}_tiktok_login_code:{code}"
         redis_init = SevenHelper.redis_init()
@@ -53,7 +56,7 @@ class TikTokHelper:
             headers = {"Content-type": "application/json"}
             response = requests.post(requset_url, headers=headers, data=SevenHelper.json_dumps(param))
             response_data = SevenHelper.json_loads(response.text)
-            if response_data["err_no"] != 0:
+            if response_data.__contains__("err_no") and response_data["err_no"] != 0:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = response_data["err_no"]
                 invoke_result_data.error_message = response_data["err_tips"]
@@ -72,15 +75,18 @@ class TikTokHelper:
             return invoke_result_data
 
     @classmethod
-    def get_access_token(self,app_id, app_secret, grant_type="client_credential"):
+    def get_access_token(self, grant_type="client_credential", app_id="", app_secret=""):
         """
         :description:access_token 是小程序的全局唯一调用凭据，开发者调用小程序支付时需要使用 access_token。access_token 的有效期为 2 个小时，需要定时刷新 access_token，重复获取会导致之前一次获取的 access_token 的有效期缩短为 5 分钟。
+        :param grant_type: 获取access_token 时值为 client_credential
         :param app_id: app_id
         :param app_secret: app_secret
-        :param grant_type: 获取access_token 时值为 client_credential
         :return: 
         :last_editors: HuangJianYi
         """
+        app_id = app_id if app_id else config.get_value("app_id")
+        app_secret = app_secret if app_secret else config.get_value("app_secret")
+
         invoke_result_data = InvokeResultData()
         param = {
             'appid': app_id,
@@ -93,7 +99,7 @@ class TikTokHelper:
             headers = {"Content-type": "application/json"}
             response = requests.post(requset_url, headers=headers, data=SevenHelper.json_dumps(param))
             response_data = SevenHelper.json_loads(response.text)
-            if response_data["err_no"] != 0:
+            if response_data.__contains__("err_no") and response_data["err_no"] != 0:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = response_data["err_no"]
                 invoke_result_data.error_message = response_data["err_tips"]
@@ -108,26 +114,28 @@ class TikTokHelper:
             return invoke_result_data
 
     @classmethod
-    def decrypt_data_by_code(self, app_id, app_secret, open_id, code, encrypted_Data, iv):
+    def decrypt_data_by_code(self, open_id, code, encrypted_Data, iv, app_id="", app_secret=""):
         """
         :description:解析加密数据，客户端判断是否登录状态，如果登录只传open_id不传code，如果是登录过期,要传code重新获取session_key
-        :param app_id: app_id
-        :param app_secret: app_secret
         :param open_id：open_id
         :param code：登录票据
         :param encrypted_Data：加密数据,抖音返回加密参数
         :param iv：抖音返回参数
+        :param app_id: app_id
+        :param app_secret: app_secret
         :return: 解密后的数据，用户信息或者手机号信息
         :last_editors: HuangJianYi
         """
+        app_id = app_id if app_id else config.get_value("app_id")
+        app_secret = app_secret if app_secret else config.get_value("app_secret")
+
         data = {}
         if code:
-            code2_session_dict = self.code2_session(app_id, app_secret, code)
+            code2_session_dict = self.code2_session(code=code, app_id=app_id, app_secret=app_secret)
             if code2_session_dict:
                 open_id = code2_session_dict["openid"]
         try:
             session_key = SevenHelper.redis_init().get(f"{app_id}_tiktok_sessionkey:{str(open_id)}")
-            app_id = config.get_value("app_id")
             data_crypt = TikTokBizDataCrypt(app_id, session_key)
             data = data_crypt.decrypt(encrypted_Data, iv)  #data中是解密的信息
         except Exception as ex:
@@ -135,16 +143,18 @@ class TikTokHelper:
         return data
 
     @classmethod
-    def decrypt_data(self, app_id, session_key, encrypted_Data, iv):
+    def decrypt_data(self, session_key, encrypted_Data, iv, app_id=""):
         """
         :description:解析加密数据
-        :param app_id: 抖音小程序标识
         :param session_key: session_key调用登录接口获得
         :param encrypted_Data：加密数据,抖音返回加密参数
         :param iv：抖音返回参数
+        :param app_id: 抖音小程序标识
         :return: 解密后的数据，用户信息或者手机号信息
         :last_editors: HuangJianYi
         """
+        app_id = app_id if app_id else config.get_value("app_id")
+
         data = {}
         try:
             data_crypt = TikTokBizDataCrypt(app_id, session_key)
@@ -197,7 +207,9 @@ class TikTokHelper:
 
 
 class TikTokPayRequest(object):
-    """配置账号信息"""
+    """
+    :description: 抖音支付请求类,配置文件内容 "tiktok_pay": {"api_key": "","cp_extra": "","token": "","salt": "","pay_notify_url": ""}
+    """
     # =======【基本信息设置】=====================================
     # 抖音公众号身份的唯一标识。审核通过后，在抖音发送的邮件中查看
     app_id = ""
@@ -205,10 +217,6 @@ class TikTokPayRequest(object):
     api_key = ""
     #开发者自定义字段，回调原样回传
     cp_extra = ""
-    #支付回调地址
-    pay_notify_url = ""
-    #退款回调地址
-    refund_notify_url = ""
     #担保交易Token（令牌）
     token = ""
     #担保交易密钥
@@ -216,16 +224,17 @@ class TikTokPayRequest(object):
     # 日志
     logger_error = Logger.get_logger_by_name("log_error")
 
-    def __init__(self, app_id, api_key, cp_extra, token, salt):
+    def __init__(self, app_id="", api_key="", cp_extra="", token="", salt=""):
         """
         :description: 初始化
         :last_editors: HuangJianYi
         """
-        self.app_id = app_id
-        self.api_key = api_key
-        self.cp_extra = cp_extra
-        self.token = token
-        self.salt = salt
+        pay_config = config.get_value("tiktok_pay")
+        self.app_id = app_id if app_id else config.get_value("app_id")
+        self.api_key = api_key if api_key else pay_config["api_key"]
+        self.cp_extra = cp_extra if cp_extra else pay_config["cp_extra"]
+        self.token = token if token else pay_config["token"]
+        self.salt = salt if salt else pay_config["salt"]
 
     def create_order(self, pay_order_no, notify_url, total_amount=1, subject="", body="", valid_time=900, thirdparty_id="", disable_msg=None, msg_page="", store_uid=""):
         """
@@ -558,9 +567,10 @@ class TikTokReponse(object):
     """
     logger_error = Logger.get_logger_by_name("log_error")
 
-    def __init__(self, data, token):
+    def __init__(self, data, token=""):
         self.data = data  #data由json.loads(self.request.body)获得
-        self.token = token
+        pay_config = config.get_value("tiktok_pay")
+        self.token = token if token else pay_config["token"]
 
     def get_data(self):
         """
