@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2021-09-14 19:29:48
+@LastEditTime: 2021-09-28 13:43:01
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -27,16 +27,18 @@ class WeChatHelper:
     logger_error = Logger.get_logger_by_name("log_error")
 
     @classmethod
-    def code2_session(self,app_id, app_secret, code, grant_type="authorization_code"):
+    def code2_session(self, code, grant_type="authorization_code",app_id="", app_secret=""):
         """
         :description:临时登录凭证校验
-        :param app_id：app_id
-        :param app_secret：app_secret
         :param code：登录票据
         :param grant_type：授权方式
+        :param app_id：app_id
+        :param app_secret：app_secret
         :return: 返回字典包含字段 session_key,openid
         :last_editors: HuangJianYi
         """
+        app_id = app_id if app_id else config.get_value("app_id")
+        app_secret = app_secret if app_secret else config.get_value("app_secret")
         invoke_result_data = InvokeResultData()
         redis_key = f"{app_id}_wechat_login_code:{str(code)}"
         redis_init = SevenHelper.redis_init()
@@ -58,7 +60,7 @@ class WeChatHelper:
         try:
             respone = requests.get(requset_url, params=param)
             respone_data = SevenHelper.json_loads(respone.text)
-            if respone_data["errcode"] != 0:
+            if respone_data.__contains__("errcode") and respone_data["errcode"] != 0:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = respone_data["errcode"]
                 invoke_result_data.error_message = respone_data["errmsg"]
@@ -76,15 +78,18 @@ class WeChatHelper:
             return invoke_result_data
 
     @classmethod
-    def get_access_token(self, app_id, app_secret, grant_type="client_credential"):
+    def get_access_token(self, grant_type="client_credential",app_id="", app_secret=""):
         """
         :description:access_token 是小程序的全局唯一调用凭据，开发者调用小程序支付时需要使用 access_token。access_token 的有效期为 2 个小时，需要定时刷新 access_token，重复获取会导致之前一次获取的 access_token 的有效期缩短为 5 分钟。
+        :param grant_type: 获取access_token 时值为 client_credential
         :param app_id:app_id
         :param app_secret:app_secret
-        :param grant_type: 获取access_token 时值为 client_credential
         :return: 
         :last_editors: HuangJianYi
         """
+        app_id = app_id if app_id else config.get_value("app_id")
+        app_secret = app_secret if app_secret else config.get_value("app_secret")
+
         invoke_result_data = InvokeResultData()
         param = {
             'appid': app_id,
@@ -96,7 +101,7 @@ class WeChatHelper:
             requset_url = 'https://api.weixin.qq.com/cgi-bin/token'
             respone = requests.get(requset_url, params=param)
             respone_data = SevenHelper.json_loads(respone.text)
-            if respone_data["errcode"] != 0:
+            if respone_data.__contains__("errcode") and respone_data["errcode"] != 0:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = respone_data["errcode"]
                 invoke_result_data.error_message = respone_data["errmsg"]
@@ -111,26 +116,28 @@ class WeChatHelper:
             return invoke_result_data
 
     @classmethod
-    def decrypt_data_by_code(self, app_id, app_secret, open_id, code, encrypted_Data, iv):
+    def decrypt_data_by_code(self, open_id, code, encrypted_Data, iv, app_id="", app_secret=""):
         """
         :description:解析加密数据，客户端判断是否登录状态，如果登录只传open_id不传code，如果是登录过期,要传code重新获取session_key
-        :param app_id：app_id
-        :param app_secret：app_secret
         :param open_id：open_id
         :param code：登录票据
         :param encrypted_Data：加密数据,微信返回加密参数
         :param iv：微信返回参数
+        :param app_id：app_id
+        :param app_secret：app_secret
         :return: 解密后的数据，用户信息或者手机号信息
         :last_editors: HuangJianYi
         """
+        app_id = app_id if app_id else config.get_value("app_id")
+        app_secret = app_secret if app_secret else config.get_value("app_secret")
+
         data = None
         if code:
-            code2_session_dict = self.code2_session(app_id, app_secret,code)
+            code2_session_dict = self.code2_session(code=code, app_id=app_id, app_secret=app_secret)
             if code2_session_dict:
                 open_id = code2_session_dict["openid"]
         try:
             session_key = SevenHelper.redis_init().get(f"{app_id}_wechat_sessionkey:{open_id}")
-            app_id = config.get_value("app_id")
             wx_data_crypt = WeChatDataCrypt(app_id, session_key)
             data = wx_data_crypt.decrypt(encrypted_Data, iv)  #data中是解密的信息
         except Exception as ex:
@@ -138,16 +145,18 @@ class WeChatHelper:
         return data
 
     @classmethod
-    def decrypt_data(self, app_id, session_key, encrypted_Data, iv):
+    def decrypt_data(self, session_key, encrypted_Data, iv, app_id=""):
         """
         :description:解析加密数据
-        :param app_id: 微信小程序标识
         :param session_key: session_key调用登录接口获得
         :param encrypted_Data：加密数据,微信返回加密参数
         :param iv：微信返回参数
+        :param app_id: 微信小程序标识
         :return: 解密后的数据，用户信息或者手机号信息
         :last_editors: HuangJianYi
         """
+        app_id = app_id if app_id else config.get_value("app_id")
+
         data = {}
         try:
             wx_data_crypt = WeChatDataCrypt(app_id, session_key)
@@ -234,8 +243,7 @@ class WeChatHelper:
 
 class WeChatPayRequest(object):
     """
-    :description: 微信支付请求类
-    :description: 配置文件内容 "wechat_pay": {"api_key": "","mch_id": "","certificate_url":""}
+    :description: 微信支付请求类,配置文件内容 "wechat_pay": {"api_key": "","mch_id": "","certificate_url":"","pay_notify_url":""}
     """
     """配置账号信息"""
     # =======【基本信息设置】=====================================
@@ -245,16 +253,17 @@ class WeChatPayRequest(object):
     mch_id = ""
     # API密钥，需要在商户后台设置
     api_key = ""
-    # 证书地址
+    # 证书地址,证书文件需要在商户后台下载
     certificate_url = ""
 
     logger_error = Logger.get_logger_by_name("log_error")
 
-    def __init__(self, app_id, api_key, mch_id, certificate_url=""):
-        self.app_id = app_id
-        self.api_key = api_key
-        self.mch_id = mch_id
-        self.certificate_url = certificate_url
+    def __init__(self, app_id="", api_key="", mch_id="", certificate_url=""):
+        pay_config = config.get_value("wechat_pay")
+        self.app_id = app_id if app_id else config.get_value("app_id")
+        self.api_key = api_key if api_key else pay_config["api_key"]
+        self.mch_id = mch_id if mch_id else pay_config["mch_id"]
+        self.certificate_url = certificate_url if certificate_url else pay_config["certificate_url"]
 
     def get_prepay_id(self, unifiedorder_url, params):
         """
@@ -272,7 +281,7 @@ class WeChatPayRequest(object):
             invoke_result_data.data = prepay_id
             return invoke_result_data
 
-        respone = requests.post(unifiedorder_url, self._get_request_xml(params), headers={'Content-Type': 'application/xml'})
+        respone = requests.post(unifiedorder_url, self.convert_request_xml(params), headers={'Content-Type': 'application/xml'})
         response_data = xmltodict.parse(respone.text.encode('ISO-8859-1').decode('utf-8'))['xml']
         if response_data['return_code'] == 'SUCCESS':
             if response_data['result_code'] == 'SUCCESS':
@@ -370,7 +379,7 @@ class WeChatPayRequest(object):
             if pay_order_no != "":
                 params['out_trade_no'] = str(pay_order_no)
 
-            request_xml = self._get_request_xml(params)
+            request_xml = self.convert_request_xml(params)
             queryorder_url = 'https://api.mch.weixin.qq.com/pay/orderquery'
             respone = requests.post(queryorder_url, request_xml, headers={'Content-Type': 'application/xml'})
             response_data = xmltodict.parse(respone.text.encode('ISO-8859-1').decode('utf-8'))['xml']
@@ -404,7 +413,7 @@ class WeChatPayRequest(object):
                 'nonce_str': WeChatHelper.get_nonce_str(),
                 'out_trade_no': str(pay_order_no)
             }
-            request_xml = self._get_request_xml(params)
+            request_xml = self.convert_request_xml(params)
             queryorder_url = 'https://api.mch.weixin.qq.com/pay/closeorder'
             respone = requests.post(queryorder_url, request_xml, headers={'Content-Type': 'application/xml'})
             response_data = xmltodict.parse(respone.text.encode('ISO-8859-1').decode('utf-8'))['xml']
@@ -464,7 +473,7 @@ class WeChatPayRequest(object):
         }
         params = WeChatHelper.get_sign(params)
         refund_url = 'https://api.mch.weixin.qq.com/secapi/pay/refund'
-        respone = post(url=refund_url, data=self._get_request_xml(params), headers={'Content-Type': 'application/xml'}, pkcs12_filename=self.certificate_url, pkcs12_password=self.mch_id)
+        respone = post(url=refund_url, data=self.convert_request_xml(params), headers={'Content-Type': 'application/xml'}, pkcs12_filename=self.certificate_url, pkcs12_password=self.mch_id)
         response_data = xmltodict.parse(respone.text.encode('ISO-8859-1').decode('utf-8'))['xml']
         if response_data['return_code'] == 'SUCCESS':
             if response_data['result_code'] == 'SUCCESS':
@@ -506,7 +515,7 @@ class WeChatPayRequest(object):
                 'sign_type': 'MD5'
             }
             params = WeChatHelper.get_sign(params)
-            request_xml = self._get_request_xml(params)
+            request_xml = self.convert_request_xml(params)
             queryrefund_url = 'https://api.mch.weixin.qq.com/pay/refundquery'
             respone = requests.post(queryrefund_url, request_xml, headers={'Content-Type': 'application/xml'})
             response_data = xmltodict.parse(respone.text.encode('ISO-8859-1').decode('utf-8'))['xml']
@@ -519,7 +528,7 @@ class WeChatPayRequest(object):
             invoke_result_data.error_message = "查询退款单出现异常"
             return invoke_result_data
 
-    def _get_request_xml(self, params):
+    def convert_request_xml(self, params):
         """
         :description:拼接XML
         :return: 
@@ -542,9 +551,10 @@ class WeChatPayReponse(object):
 
     logger_error = Logger.get_logger_by_name("log_error")
 
-    def __init__(self, reponse_xml, api_key):
+    def __init__(self, reponse_xml, api_key=""):
         self.data = WeChatHelper.xml_to_array(reponse_xml)
-        self.api_key = api_key
+        pay_config = config.get_value("wechat_pay")
+        self.api_key = api_key if api_key else pay_config["api_key"]
 
     def check_sign(self):
         """
@@ -567,7 +577,7 @@ class WeChatPayReponse(object):
         """
         return self.data
 
-    def response_xml(self, msg, ok=True):
+    def convert_response_xml(self, msg, ok=True):
         """
         :description: 返回xml格式数据
         :return:
@@ -583,9 +593,10 @@ class WeChatRefundReponse(object):
     """
     logger_error = Logger.get_logger_by_name("log_error")
 
-    def __init__(self, reponse_xml, api_key):
+    def __init__(self, reponse_xml, api_key=""):
         self.data = WeChatHelper.xml_to_array(reponse_xml)
-        self.api_key = api_key
+        pay_config = config.get_value("wechat_pay")
+        self.api_key = api_key if api_key else pay_config["api_key"]
 
     def get_data(self):
         """
@@ -605,7 +616,7 @@ class WeChatRefundReponse(object):
         dict_req_info = xmltodict.parse(detail_info)
         return dict_req_info
 
-    def response_xml(self, msg, ok=True):
+    def convert_response_xml(self, msg, ok=True):
         code = "SUCCESS" if ok else "FAIL"
         return WeChatHelper.array_to_xml(dict(return_code=code, return_msg=msg))
 
