@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-09-06 19:34:41
+@LastEditTime: 2021-09-26 14:00:08
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -108,7 +108,7 @@ class AssetBaseModel():
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "资产类型为价格档位,参数asset_object_id不能为空或等于0"
             return invoke_result_data
-
+        asset_value = int(asset_value)
         user_asset_id_md5 = self._get_user_asset_id_md5(act_id, user_id, asset_type, asset_object_id)
         if user_asset_id_md5 == 0:
             invoke_result_data.success = False
@@ -268,7 +268,7 @@ class AssetBaseModel():
                 redis_init.hset(only_cache_key, only_id, 1)
                 redis_init.expire(only_cache_key, 24 * 3600)
 
-            invoke_result_data.data = user_asset.asset_value
+            invoke_result_data.data = {"user_asset":user_asset.__dict__}
 
         except Exception as ex:
             if self.context:
