@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2021-09-09 10:58:50
+@LastEditTime: 2021-09-23 18:03:00
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -418,7 +418,7 @@ class UserBaseModel(FrameBaseModel):
                 invoke_result_data.error_code = "fail"
                 invoke_result_data.error_message = "系统繁忙,请稍后再试"
                 return invoke_result_data
-            
+            invoke_result_data.data = {"user_info":user_info.__dict__}
             self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
 
         except Exception as ex:
@@ -539,7 +539,8 @@ class UserBaseModel(FrameBaseModel):
             user_info_model.update_entity(user_info, "user_state,modify_date,modify_date")
         elif audit_status == 3:
             user_black_model.update_table(condition, "id=%s", params)
-
+         
+        invoke_result_data.data = {"user_info":user_info.__dict__}
         self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
         
         return invoke_result_data
@@ -647,9 +648,10 @@ class UserBaseModel(FrameBaseModel):
 
         page_list, total = UserBlackModel(context=self.context).get_dict_page_list("*", page_index, page_size, condition, order_by=order_by, params=params)
         for user_black in page_list:
-            user_black["refund_order_data"] = self.json_loads(user_black["refund_order_data"]) if user_black["refund_order_data"] else []
+            user_black["refund_order_data"] = SevenHelper.json_loads(user_black["refund_order_data"]) if user_black["refund_order_data"] else []
 
         page_info = PageInfo(page_index, page_size, total, page_list)
+        return page_info
 
     def check_pull_black(self,user_info_dict,is_black,refund_count,all_order_data):
         """
